pub enum JoinRule {
JoinHolidays,
JoinBusinessDays,
}Expand description
How to combine the business days of several calendars.
Variants
JoinHolidays
A date is a business day only if it is a business day in every calendar (the union of holidays). Standard for multi-currency curves.
JoinBusinessDays
A date is a business day if it is a business day in any calendar (the intersection of holidays).