#[non_exhaustive]pub enum DateGeneration {
Backward,
Forward,
Zero,
ThirdWednesday,
}Expand description
How the regular date grid is generated and where a stub may fall.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Backward
Regular dates measured backward from the termination date.
Forward
Regular dates measured forward from the effective date.
Zero
No intermediate dates: just effective and termination.
ThirdWednesday
Like Backward but each date is snapped to the third
Wednesday of its month (IMM dates).